<?php
if(!defined('TEMPLATEPATH')) {
	define( 'TEMPLATEPATH', get_bloginfo('stylesheet_directory'));
}

if (function_exists('register_sidebar')) {
	register_sidebar(array(
		'name'=> __('mariginari bar', 'mariginari'),
		'id' => 'mariginari-bar',
		'before_widget' => '<li id="%1$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
}

if ( ! function_exists( 'mariginari_init' ) ) :
function mariginari_init() {

	load_theme_textdomain ('mariginari');

	define('MARIGINARI_THEME_IS_ACTIVE', true);
	define('MARIGINARI_MONTHLY_ARCHIVE_DATE_FORMAT', "F Y");
	define('MARIGINARI_PREFERS_WYSIWYG_COMMENTS', true);

	if ( function_exists('add_editor_style') ) {
		add_editor_style('editor-style.css.php');
	}

	if ( function_exists('add_theme_support') ) {
		// Add default posts and comments RSS feed links to head
		add_theme_support( 'automatic-feed-links' );
	}

	$GLOBALS['mariginari'] = new Mariginari();
}
endif;
if(version_compare(get_bloginfo('version'), '3.0') < 0) {
	mariginari_init();
}
else {
	add_action( 'after_setup_theme', 'mariginari_init' );
}

class Mariginari {

	function __construct() {

		// Hook up theme and plugins' JavaScript.
		add_action( 'wp_print_scripts', array($this, 'script') );

		// Work around miscapitalization in translation.
		add_filter( 'get_comment_date', array( $this, $this->get_date_wrapper() )  );

		// Comment / ping separation based on http://sivel.net/2008/10/wp-27-comment-separation/
		add_filter( 'get_comments_number', array($this, 'comment_count'), 0 );

		// use either WYSIWYG Comments or Comment Preview, not both, according to preference.
		// this allows for flexible switching btw the two, possibly saving users from a broken interface
		// during transitions; it is *not* meant to replace the actual plugin en-/disabling.
		if ( $this->has_comment_preview() && $this->has_wysiwyg_comments() ) {
			if ( $this->prefers_wysiwyg_comments() ) {
				$this->disable_comment_preview();
			}
			else {
				$this->disable_wysiwyg_comments();
			}
		}
	}
	function script() {
		wp_enqueue_script('mariginari-script', TEMPLATEPATH.'/javascript.php', array(), '9001');
	}
	function comment_count( $count ) {
	        global $id;

		if ( is_admin() ) {
		        return $count;
		}

	        $comments_by_type = &separate_comments(get_comments('status=approve&post_id=' . $id));
	        return count($comments_by_type['comment']);
	}



	public function echo_404_suggestions() {
		$suggestions = $this->get_404_suggestions();
		if ($suggestions === false) {
			echo "<p>".__("This address doesn't have a specific post attached to it, "
				."and no posts related to what you requested were found. This might be due to", 'mariginari')."</p>";
		}
		else {
			echo "<p>";
			_e("This address doesn't have a specific post attached to it.", 'mariginari');
			echo " " . $suggestions;
			echo "</p>";
			echo "<p>".__("If this wasn't what you were looking for, it might be due to", 'mariginari')."</p>";
		}
		echo "<ul>
			<li>".__('a post or archive page having been removed', 'mariginari')."</li>
			<li>".__('a broken link', 'mariginari')."</li>
			<li>".__('a typing error.', 'mariginari')."</li>
</ul>";
		echo "<p>".sprintf(__('Please try the search function below or '
			.'<a href="%1$s" title="Archive by date at the sidebar">the yearly archive in the sidebar</a>. '
			.'You can also go back in post history using the "Older Posts" link at the '
			.'<a href="%2$s">bottom of the front page</a>.', 'mariginari'),
			'#collapsible-archive', get_bloginfo('url').(substr(get_bloginfo('url'),-1) == '/' ? '' : '/').'#chronology')."</p>";
		?><form method="get" id="bigsearchform" action="<?php bloginfo('url'); ?>">
		<div>
			<label for="s"><?php _e('Search for...', 'mariginari'); ?></label>
			<input class="text" type="text" value="<?php
				echo trim(htmlentities(stripslashes(urldecode(get_query_var('name'))))); ?>" name="s" id="s" />
			<input type="submit" class="submit" name="Submit" value="<?php _e('Go!', 'mariginari'); ?>" />
		</div>
	</form><?php
	}

	// Mimicked this from http://svn.automattic.com/wordpress/trunk/wp-includes/canonical.php
	function get_404_suggestions() {
		global $wpdb;

		if ( !get_query_var('name') )
			return false;

		// Store for re-use later.
		$name = get_query_var('name');

		// if any of year, monthnum, or day are set, use them to refine the query
		if ( get_query_var('year') )
			$where_date = $wpdb->prepare(" AND YEAR(post_date) = %d", get_query_var('year'));
		if ( get_query_var('monthnum') )
			$where_date = $wpdb->prepare(" AND MONTH(post_date) = %d", get_query_var('monthnum'));
		if ( get_query_var('day') )
			$where_date = $wpdb->prepare(" AND DAYOFMONTH(post_date) = %d", get_query_var('day'));

		$where = $wpdb->prepare("post_name LIKE %s", $name . '%') .$where_date;
		$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");

		if ( !$post_id ) {
			$where = $wpdb->prepare("post_name LIKE %s", '%' . $name) .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_name LIKE %s", '%' . $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", '%' . $name) .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", '%' . $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}

		if ( !$post_id ) {
			return false;
		}
		return '<span class="mariginari-suggestions">'
				.sprintf(__('Did you mean: %s', 'mariginari'),
					'<a href="'.get_permalink($post_id)
					.'" title="'.$this->get_the_title_attribute($post_id).'"><em><strong>'
					.get_the_title($post_id).'</strong></em></a>')
			.'</span>';
	}


	// WP's the_title_attribute() is crap.
	public function get_the_title_attribute($ID = 0) {
		$title = get_the_title($ID);

		if ( strlen($title) == 0 )
			return;

		return esc_attr(strip_tags($title));
	}

	public function get_monthly_archive_date_format() {
		return MARIGINARI_MONTHLY_ARCHIVE_DATE_FORMAT;
	}
	public function get_date_wrapper() {
		$options = get_option("mariginari");
		return $options['date_wrapper'] ? 'date_ucfirst' : 'date_unchanged';
	}
	public function date_ucfirst($date) {
		return ucfirst(strtolower($date));
	}
	public function date_unchanged($date) {
		return $date;
	}




	// some abstract meta-functions for functionality-detection and on-the-fly en-/disabling.
	// these need to be updated with the plugins or if the plugin providing the functionality is changed.
	public function prefers_wysiwyg_comments() {
		return MARIGINARI_PREFERS_WYSIWYG_COMMENTS;
	}
	public function has_wysiwyg_comments() {
		return has_action('wp_head', 'mcecomment_init');
	}
	public function uses_wysiwyg_comments() {
		return ( !$this->has_comment_preview() ? 'true' : 'false');
		return ( $this->has_wysiwyg_comments() && ( $this->prefers_wysiwyg_comments() || !$this->has_comment_preview() ) );
	}
	public function disable_wysiwyg_comments() {
		return remove_action('wp_head', 'mcecomment_init');
	}
	public function has_comment_preview() {
		return has_action('comment_form', 'lcp_add_preview_div');
	}
	public function disable_comment_preview() {
		return remove_action('comment_form', 'lcp_add_preview_div');
	}
	public function uses_comment_preview() {
		return ( $this->has_comment_preview() && !$this->prefers_wysiwyg_comments() );
	}



	public function tags_page_tags_list() {
		$show_em_like_this = array(
		'smallest'  => 4, 
		'largest'   => 32,
		'unit'      => 'pt', 
		'number'    => 0,  
		'format'    => 'list',
		'separator' => '
	',
		'orderby'   => 'name', 
		'order'     => 'ASC',
//		'exclude'   => ,
//		'include'   => ,
		'link'      => 'view', 
		'taxonomy'  => 'post_tag', 
		'echo'      => true
		);

		wp_tag_cloud($show_em_like_this);
	}

	public function categories_page_categories_list() {
		$show_em_like_this = array(
//			'show_option_all'    => ,
			'orderby'            => 'name',
			'order'              => 'ASC',
			'show_last_update'   => 0,
			'style'              => 'list',
			'show_count'         => 1,
			'hide_empty'         => 1,
			'use_desc_for_title' => 1,
			'child_of'           => 0,
//			'feed'               => ,
//			'feed_type'          => ,
			'feed_image'         => get_bloginfo('template_url').'/images/rss-12.png',
//			'exclude'            => ,
//			'exclude_tree'       => ,
//			'include'            => ,
			'current_category'   => 0,
			'hierarchical'       => true,
			'title_li'           => '',
			'number'             => NULL,
			'echo'               => 1,
			'depth'              => 0
		);

		echo '<ul class="all-categories">';
		wp_list_categories($show_em_like_this);
		echo '</ul>';
	}

	// http://erikt.tumblr.com/post/278953342/get-a-wordpress-page-id-with-the-slug
	function get_ID_by_slug($slug) {
		$page = get_page_by_path($slug);
		if ($page) {
			return $page->ID;
		} else {
			return null;
		}
	}
	public function post() {
		global $post;

		if ( is_404() ) {
			$id = $this->get_ID_by_slug(__('404-not-found', 'mariginari'));
			if (is_numeric($id)) {
				$post = get_post($id);
				setup_postdata($post);
			}
			else {
				// a quick and nasty fallback.
				?><div class="article not-found">
					<h2 class="post-title"><?php _e("Let's find that post!", 'mariginari'); ?></h2>
					<div class="content"><?php $this->echo_404_suggestions(); ?></div>
				</div><!-- end post --><?php
				return;
			}
		}
		?>




			<li <?php post_class(  'article'. ( is_single() ? ' single' : '' )  ); ?> id="post-<?php the_ID();?>">
<?php $this->post_header();
		if ( is_404() ) {
			$this->echo_404_suggestions();
		}
		else {
			the_content();
			if (  is_page( (get_option('category_base') ? get_option('category_base') : 'category') )  ) {
				$this->categories_page_categories_list();
			}
			if (  is_page( (get_option('tag_base') ? get_option('tag_base') : 'tag') )  ) {
				$this->tags_page_tags_list();
			}
		}

		$this->post_footer();
?>
			</li><!-- end post -->


<?php
	}

	public function post_header() {
		$date_wrapper = $this->get_date_wrapper();
		?>
				<div class="header">
					<h1>
						<a href="<?php the_permalink() ?>"
						  title="<?php printf(
							__('Permanent Link: %s', 'mariginari'), 
							the_title_attribute('before=&after=&echo=0')
						  ); ?>"
					  	rel="bookmark"><?php the_title(); ?></a>
					</h1>
					<h2>
						<a href="<?php bloginfo('url'); ?>/?p=<?php the_ID(); ?>"
						  title="<?php printf( __('Permanent Link: Post no. %d', 'mariginari'), get_the_ID() ); ?>"
						  rel="bookmark">#<?php the_ID();?></a>.
						<?php echo sprintf(
							__('%s at %s', 'mariginari'),
							ucfirst(get_the_time(get_option('date_format'))),
							get_the_time(get_option('time_format'))
						);
						echo ' | ';
						if (get_the_author_meta('user_url') != '') {
							?><a href="<?php the_author_meta('user_url'); ?>" title="<?php
							_e("Visit the author's homepage", 'mariginari'); ?>"><?php the_author(); ?></a><?php 
						}
						else {
							the_author();
						}
						edit_post_link(__('Edit'), '
						| ', '');
						?>

					</h2>
				</div><!-- end post header -->

				<div class="section content">
<?php
	}

	public function feedback_link() {
		?><h2 class="feedback-link"><?php

		if ( function_exists('mariginari_get_ttweet_reply_button') ) {
			$tt = mariginari_get_ttweet_reply_button( get_the_ID() );
			if (!empty($tt)) {
			?>

						<?php echo $tt; ?> <?php
			}
		}

		if ( function_exists('mariginari_get_rettweet_button') ) {
			$tt = mariginari_get_rettweet_button( get_the_ID() );
			if (!empty($tt)) {
			?>

						<?php echo $tt; ?> <?php
			}
		}

		if ( function_exists('ADDTOANY_SHARE_SAVE_ICONS') ) {
			ob_start();
			ADDTOANY_SHARE_SAVE_ICONS( array("html_wrap_open" => "", "html_wrap_close" => "") );
			$aa = ob_get_contents();
			ob_end_clean();
			if (!empty($aa)) {
			?>

						<?php echo $aa; ?> <?php
			}
		}
		if ( function_exists('ADDTOANY_SHARE_SAVE_BUTTON') ) {
			ob_start();
			ADDTOANY_SHARE_SAVE_BUTTON( array("html_wrap_open" => "", "html_wrap_close" => "") );
			$aa = ob_get_contents();
			ob_end_clean();
			if (!empty($aa)) {
			?>

						<?php echo $aa; ?> <?php
			}
		}
		?>

						<?php
		comments_popup_link( comments_open() ? __('Care to leave a comment?', 'mariginari') : __('No comments', 'mariginari'),
			__('1 Comment', 'mariginari'), __('% Comments ', 'mariginari'), 'feedback-link',
			__('Comments are closed for this post', 'mariginari'));
		echo '
					</h2>';
	}
	public function post_footer() {
		?>
				</div><!-- end post content -->

				<div class="footer">
					<?php
		wp_link_pages('before=<h2 class="pages">'.__('Pages:', 'mariginari').'&after=</h2>&pagelink=%');
		if ( !is_singular() ) {
			$this->feedback_link();
		}
		if( get_the_tag_list() ) {
?>

					<?php the_tags('<h2 class="taxonomy tags">
'.__('Tags:
', 'mariginari'),',
','
					</h2>');
?><?php
				}
				else {
?>

					<h2 class="taxonomy none">&nbsp;</h2>
<?php
				}
?>

				</div><!-- end post footer -->
<?php
	}

	public function nav_between_posts() {
		?>
		<div class="nav between posts">
		<ul>
			<li class="prev"><?php previous_post_link('%link'); ?></li>
			<li class="next"><?php next_post_link('%link'); ?></li>
		</ul>
		</div>

<?php
	}
	public function nav_between_archive_pages() {
		global $wp_query;
		$current = ($wp_query->max_num_pages > 1 ? '<li class="currently-browsing">'.$this->get_paged_pages().'</li>' : '');
		?>	<div class="nav between archive-pages" id="chronology">
			<ul>
				<li class="prev"><?php previous_posts_link( __('Newer Posts', 'mariginari') ); ?></li>
			<?php echo $current; ?>

				<li class="next"><?php next_posts_link( __('Older Posts', 'mariginari') ); ?></li>
			</ul>
			</div>

<?php
	}


	public function get_currently_browsing() {
		global $wp_query;
		global $s;
		$currently = '';
		if ( is_home() ) {
			$currently .= sprintf(__('Newest posts', 'mariginari') );
		}
		else if ( is_search() ) {
			$searched_for = trim( wp_specialchars($s,1) );
			$searched_for = ( empty($searched_for) ? __('nothing', 'mariginari') : $searched_for );
			$currently .= sprintf(__('Search results for %1$s', 'mariginari'), '<em><strong>'.$searched_for.'</strong></em>');
		}
		else if ( is_category() ) {
			$currently .= sprintf(__('Posts in category %1$s', 'mariginari'), single_cat_title('', false) );
		}
		else if ( is_tag() ) {
			$currently .= sprintf(__('Posts tagged with %s', 'mariginari'), single_tag_title('', false) );
		}
		else if ( is_author() ) {
			global $wp_query;
			$curauth = $wp_query->get_queried_object();
			if ( empty($curauth) ) {
				$nick = $_GET['author'];
			}
			$currently .= sprintf(__('Posts written by %s', 'mariginari'), $curauth->display_name  );
		}
		else {
			$currently .= __('The archives ', 'mariginari');
			if ( is_day() ) {
				$currently .= sprintf( __('for %s', 'mariginari'), get_the_time(get_option('date_format')) );
			}
			else if ( is_month() ) {
				$currently .= sprintf( __('for %s', 'mariginari'), get_the_time($this->get_monthly_archive_date_format()) );
			}
			else if ( is_year() ) {
				$currently .= sprintf(__('for %s', 'mariginari'), get_the_time(__('Y', 'mariginari')) );
			}
		}
		return $currently;
	}

	public function get_currently_browsing_page() {
		global $wp_query;
		global $paged;
		$currently = $this->get_currently_browsing();
		if ( !empty($currently) && $wp_query->max_num_pages > 1) {
			if ($paged > 0) {
				$cp = $paged;
				$pat = '/\/'.$paged.'\/?$/';
				$last = preg_replace($pat,'/'.$wp_query->max_num_pages.'/', $_SERVER["REQUEST_URI"]);
			}
			else {
				$cp = 1;
				$last = $_SERVER["REQUEST_URI"] . 'page/'.$wp_query->max_num_pages.'/';
			}
			if ($paged == $wp_query->max_num_pages) {
				$currently .= sprintf( __(', page %1$d of %1$d', 'mariginari'), $wp_query->max_num_pages);
			}
			else {
				$currently .= sprintf( __(', page %1$d of <a href="%2$s" title="Page %3$d of %3$d">%3$d</a>', 'mariginari'), $cp, $last, $wp_query->max_num_pages);
			}
		}
		return '			<div class="currently-browsing">'.$currently.'</div>';
	}

	public function get_paged_pages() {
		global $wp_query;
		global $paged;
		$paged_pages = '';
		if ($wp_query->max_num_pages > 1) {
			$page_base = 'page';
			if ($paged > 0) {
				$cp = $paged;
				$pat = '@/'.$paged.'/$@';
				$paged_uri_base = preg_replace($pat, '/', $_SERVER["REQUEST_URI"]);
				$unpat = '@/'.$page_base.'/'.$paged.'/$@';
				$unpaged_uri_base = preg_replace($unpat, '/', $_SERVER["REQUEST_URI"]);
			}
			else {
				$cp = 1;
				$paged_uri_base = $unpaged_uri_base . $page_base . '/';
				$unpaged_uri_base = $_SERVER["REQUEST_URI"];
			}

			$pages = array();
			$paging_limit = 5;	// keep it odd!
			$prefix = '';
			$trailer = '';
			if ($wp_query->max_num_pages > $paging_limit) {
				if ( $cp-($paging_limit / 2) < 1 ) {
					$start_from = 1;
				}
				else {
					if ($wp_query->max_num_pages - $cp-floor($paging_limit / 2) < $paging_limit) {
						$start_from = $wp_query->max_num_pages - $paging_limit +1;
					}
					else {
						$start_from = $cp-floor($paging_limit / 2);
					}

					if ($start_from > 1) {
						$prefix = '<a href="'.$unpaged_uri_base.'" title="'
							.sprintf( __('Page 1 of %1$d', 'mariginari'), $wp_query->max_num_pages ).'">&laquo;</a>';
					}
				}
				if ( $cp+($paging_limit / 2) > $wp_query->max_num_pages ) {
					$go_until = $wp_query->max_num_pages;
				}
				else {
					if ( $cp+($paging_limit / 2) < $paging_limit ) {
						$go_until = $paging_limit;
					}
					else {
						$go_until = floor( $cp+($paging_limit / 2) );
					}

					if ($go_until < $wp_query->max_num_pages) {
						$trailer = '<a href="'.$paged_uri_base.$wp_query->max_num_pages.'/" title="'
							.sprintf( __('Page %1$d of %1$d', 'mariginari'), $wp_query->max_num_pages ).'">&raquo;</a>';
					}
				}
			}
			else {
				$start_from = 1;
				$go_until = $wp_query->max_num_pages;
			}

			if ($start_from == 1) {
				$pages[1] = '<a href="'.$unpaged_uri_base.'" title="'
						.sprintf( __('Page 1 of %1$d', 'mariginari'), $wp_query->max_num_pages ).'">1</a>';
				$start_from = 2;
			}
			for ($i = $start_from; $i <= $go_until; $i++) {
				$pages[$i] = '<a href="'.$paged_uri_base.$i.'/" title="'
					.sprintf( __('Page %1$d of %2$d', 'mariginari'), $i, $wp_query->max_num_pages ).'">'.$i.'</a>';
			}
			$pages[$cp] = '<span title="'.sprintf( __('Page %1$d of %2$d', 'mariginari'), $cp, $wp_query->max_num_pages )
					.'" class="current-paged-page">'.$cp.'</span>';
			$paged_pages = $prefix .' '. implode(' ', $pages) .' '. $trailer;
		}
		return $paged_pages;
	}

	public function list_comments($comment, $args, $depth) {

		$GLOBALS['comment'] = $comment;
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">

		<div class="header">
			<h2 class="meta">
				<?php edit_comment_link(__('e', 'mariginari')); ?>
				<?php printf(__('%1$s at %2$s', 'mariginari'), get_comment_date(), get_comment_time()); ?>.
				<a href="<?php echo htmlspecialchars(get_comment_link($comment->comment_ID ) ) ?>"
				  title="<?php _e('Permanent link to this comment', 'mariginari'); ?>"><?php printf('#%d', get_comment_ID());?></a>
			</h2>

			<span class="comment-author vcard"><?php echo get_avatar($comment,$size='32'); ?>
			<?php printf('<cite class="comment-citation">%s</cite>', get_comment_author_link()) ?></span>
		</div>

		<div class="section content"><?php comment_text() ?></div>

		<div class="footer">
			<?php if ($comment->comment_approved == '0') : ?>
			<p class="is-in-moderation"><strong><?php _e('This comment is in moderation.', 'mariginari'); ?></strong></p>
			<?php endif; ?>

			<?php if ( get_option('thread_comments') ) : ?>
			<p class="reply-link">
				<?php comment_reply_link(
					array_merge(
						$args,
						array(
							'add_below' => 'comment',
							'depth' => $depth,
							'max_depth' => $args['max_depth'],
							'reply_text' => sprintf(__('Reply to comment %d', 'mariginari'),
							$comment_count)
						)
					)
				); ?>
			</p>
			<?php endif; ?>
		</div>
<?php
	}

	public function list_pings($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>"><a href="<?php
			echo htmlspecialchars(get_comment_link($comment->comment_ID ) ) ?>"
			title="<?php _e('Permanent link to this pingback', 'mariginari'); ?>"><?php
			printf(__('%1$s at %2$s', 'mariginari'), get_comment_date('j. F\t\a Y'), get_comment_time()) ?></a>
			| <?php printf('<cite class="comment-citation">%s</cite>', get_comment_author_link()) ?>

		<?php if ($comment->comment_approved == '0') {
			echo '<p class="moderated"><strong>'.__('This comment is currently in a moderation queue.', 'mariginari').'</strong></p>';
		}
		?><div class="reply-link">
			<?php comment_reply_link( array_merge(
				$args, array(
					'add_below' => 'div-comment',
					'depth' => $depth,
					'max_depth' => $args['max_depth'],
					'reply_text' => sprintf(
						__('Reply to comment %d', 'mariginari'),
						$comment_count
					)
				)
			) ) ?>
		</div>
		<?php
	}

	public function get_tabs() {
		$about_slug = 'tietoa-blogista';
		$about_intl_slug = 'about';

		$uri = get_bloginfo('siteurl');
		$uri = ( substr($uri, -1) == '/' ? $uri : $uri . '/' );

		$home = (is_home() ? ' is-current' : '');
		$home_uri = $uri;
		$home_title = __('Home page', 'mariginari');
		$home_link_text = __('Home', 'mariginari');

		$about = (is_page($about_slug) ? ' is-current' : '');
		$about_uri = $uri . $about_slug . '/';
		$about_title = __('About the blog and the author', 'mariginari');
		$about_link_text = __('About', 'mariginari');

		$about_intl = (is_page($about_intl_slug) ? ' is-current' : '');
		$about_intl_uri = $uri . $about_intl_slug . '/';
		$about_intl_title = __('About the blog and the author (in English)', 'mariginari');
		$about_intl_link_text = __('About (en)', 'mariginari');

		$search = (is_search() ? ' is-current' : '');
		$search_form = "<div><form id=\"searchform\" method=\"get\" action=\"" . get_bloginfo('home') . "/\">
			<input type=\"text\" name=\"s\" id=\"s\" />
			<input type=\"submit\" value=\"".__('Search', 'mariginari')."\" />
			</form></div>";

		$tabs = '<ul class="tabs">
		<li class="home'.$home.'"><a href="'.$home_uri.'" title="'.$home_title.'">'.$home_link_text.'</a></li>
		<li class="about'.$about.'"><a href="'.$about_uri.'" title="'.$about_title.'">'.$about_link_text.'</a></li>
		<li class="about-international'.$about_intl.'"><a href="'.$about_intl_uri.'" title="'.$about_intl_title.'">'.$about_intl_link_text.'</a></li>
		<li class="search'.$search.'">'.$search_form.'</li>
	</ul>';
		return $tabs;
	}
}
?>
